import 'package:bmcommons/bmcommons.dart';
import 'package:flutter/material.dart';
import 'package:velocity_components/widgets/buttons/custom_button.dart';
import 'package:velocity_components/widgets/drawer/drawer_tile.dart';

class VelocityDrawerContainer extends StatefulWidget {
  final Widget header;
  final List<DrawerTile> tiles;
  final Function() onSignOutPressed;
  final Widget child;

  VelocityDrawerContainer({
    Key key,
    this.header,
    this.tiles = const [],
    this.onSignOutPressed,
    this.child,
  }) : super(key: key);

  @override
  _VelocityDrawerContainerState createState() => _VelocityDrawerContainerState();
}

class _VelocityDrawerContainerState extends State<VelocityDrawerContainer> {
  bool open = false;

  @override
  Widget build(BuildContext context) {
    return Row(
      crossAxisAlignment: CrossAxisAlignment.stretch,
      children: [
        AnimatedContainer(
          duration: Duration(milliseconds: 400),
          curve: Curves.easeOutExpo,
          width: open ? 215 : 80,
          color: Colors.white,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              Expanded(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: [
                    VerticalSpacing(),
                    Padding(
                      padding: Spacing.standardVerticalPadding,
                      child: Container(
                        height: 38,
                        child: Visibility(
                          visible: widget.header != null && open,
                          child: widget.header,
                        ),
                      ),
                    ),
                    Expanded(
                      child: ListView.builder(
                        padding: const EdgeInsets.all(0),
                        itemCount: widget.tiles.length,
                        itemBuilder: (context, i) {
                          return widget.tiles
                              .map(
                                (e) => DrawerTile(
                                  title: e.title,
                                  icon: e.icon,
                                  onPressed: e.onPressed,
                                  selected: e.selected,
                                  open: open,
                                ),
                              )
                              .toList()[i];
                        },
                      ),
                    ),
                    Visibility(
                      visible: open,
                      child: SafeArea(
                        child: Padding(
                          padding: Spacing.standardPadding,
                          child: VelocityButton(
                            title: 'Logout',
                            onPressed: widget.onSignOutPressed,
                          ),
                        ),
                      ),
                    ),
                    SafeArea(
                      child: IconButton(
                        icon: Icon(open ? Icons.chevron_left : Icons.chevron_right),
                        onPressed: () => this.setState(() {
                          open = !open;
                        }),
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
        Expanded(
          child: widget.child,
        ),
      ],
    );
  }
}
