import 'package:bmcommons/bmcommons.dart';
import 'package:flutter/material.dart';
import 'package:velocity_components/widgets/shadowed_container.dart';

class StatBox extends StatelessWidget {
  final String title;
  final String subtitle;
  final Color color;
  final IconData icon;

  const StatBox({
    Key key,
    @required this.title,
    @required this.subtitle,
    @required this.color,
    @required this.icon,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ShadowedContainer(
      height: 125,
      child: Transform.translate(
        offset: Offset(-8, 0),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Padding(
              padding: const EdgeInsets.only(bottom: 16),
              child: Container(
                alignment: Alignment.center,
                height: 50,
                width: 50,
                decoration: BoxDecoration(
                  color: color.withOpacity(0.2),
                  borderRadius: BorderRadius.circular(25),
                ),
                child: Icon(
                  icon,
                  color: color,
                ),
              ),
            ),
            HorizontalSpacing(16),
            Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Flexible(
                  child: Text(
                    title,
                    style: Theme.of(context).textTheme.headline2,
                  ),
                ),
                VerticalSpacing(4),
                Text(
                  subtitle,
                  style: Theme.of(context).textTheme.bodyText1,
                ),
              ],
            )
          ],
        ),
      ),
    );
  }
}
