import 'package:bmcommons/bmcommons.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:velocity_components/constants/_constants.dart';

class VelocityTextField extends StatefulWidget {
  final String initialText;
  final TextEditingController controller;
  final TextCapitalization capitalization;
  final bool obscureText;
  final bool enabled;
  final String caption;
  final String placeholder;
  final TextInputType keyboardType;
  final Function(String) onChanged;
  final Function(String) onSubmitted;
  final int maxLines;

  VelocityTextField({
    Key key,
    this.initialText = '',
    this.controller,
    this.obscureText = false,
    this.enabled = true,
    this.keyboardType = TextInputType.text,
    this.caption,
    this.placeholder,
    this.capitalization = TextCapitalization.sentences,
    this.onChanged,
    this.onSubmitted,
    this.maxLines = 1,
  }) : super(key: key);

  @override
  _VelocityTextFieldState createState() => _VelocityTextFieldState();
}

class _VelocityTextFieldState extends State<VelocityTextField> {
  TextEditingController controller;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();

    controller = widget.controller ?? TextEditingController();
    controller.text = controller.text.isEmpty ? widget.initialText : controller.text;
  }

  @override
  Widget build(BuildContext context) {
    return IgnorePointer(
      ignoring: !widget.enabled,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          Visibility(
            visible: widget.caption != null,
            child: Text(
              widget.caption?.toUpperCase() ?? '',
              style: caption,
            ),
          ),
          Visibility(
            visible: widget.caption != null,
            child: VerticalSpacing(4),
          ),
          Container(
            height: null,
            child: CupertinoTextField(
              decoration: BoxDecoration(
                color: widget.enabled ? Color(0x33E0E7FF) : darkBlue.withOpacity(0.2),
                border: Border.all(color: Color(0xFFE0E7FF), width: 1),
                borderRadius: BorderRadius.circular(5),
              ),
              maxLines: widget.maxLines,
              keyboardType: widget.keyboardType,
              style: headline5.copyWith(color: widget.enabled ? null : Colors.white),
              placeholder: widget.placeholder,
              obscureText: widget.obscureText,
              controller: controller,
              textCapitalization: widget.capitalization,
              onChanged: widget.onChanged,
              onSubmitted: widget.onSubmitted,
            ),
          ),
        ],
      ),
    );
  }
}
